@@ -14,6 +14,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <config-kmymoney.h>
+
 #include "kfindtransactiondlg.h"
 
 // ----------------------------------------------------------------------------
@@ -41,7 +43,6 @@
 #include <kpushbutton.h>
 #include <klineedit.h>
 #include <kcombobox.h>
-#include <kstdguiitem.h>
 #include <kiconloader.h>
 
 // ----------------------------------------------------------------------------
@@ -98,7 +99,7 @@ void KSortOptionDlg::setSortOption(const QString& option, const QString& def)
   }
 }
 
-QString KSortOptionDlg::sortOption(void) const
+QString KSortOptionDlg::sortOption() const
 {
   QString rc;
   if (!d->ui.m_useDefault->isChecked()) {
@@ -107,7 +108,7 @@ QString KSortOptionDlg::sortOption(void) const
   return rc;
 }
 
-void KSortOptionDlg::hideDefaultButton(void)
+void KSortOptionDlg::hideDefaultButton()
 {
   d->ui.m_useDefault->hide();
 }
@@ -121,6 +122,8 @@ KFindTransactionDlg::KFindTransactionDlg(QWidget *parent) :
   m_ui->setupUi(this);
   setMainWidget(m_ui->m_tabWidget);
 
+  setButtons(KDialog::Help | KDialog::Close | KDialog::Reset | KDialog::Apply);
+
   m_ui->ButtonGroup1->setId(m_ui->m_amountButton, 0);
   m_ui->ButtonGroup1->setId(m_ui->m_amountRangeButton, 1);
 
@@ -137,6 +140,7 @@ KFindTransactionDlg::KFindTransactionDlg(QWidget *parent) :
   setupDatePage();
   setupAmountPage();
   setupPayeesPage();
+  setupTagsPage();
   setupDetailsPage();
 
   // We don't need to add the default into the list (see ::slotShowHelp() why)
@@ -146,6 +150,7 @@ KFindTransactionDlg::KFindTransactionDlg(QWidget *parent) :
   m_helpAnchor[m_ui->m_amountTab] = QString("details.search.amount");
   m_helpAnchor[m_ui->m_categoryTab] = QString("details.search.category");
   m_helpAnchor[m_ui->m_payeeTab] = QString("details.search.payee");
+  m_helpAnchor[m_ui->m_tagTab] = QString("details.search.tag"); //FIXME-ALEX update Help
   m_helpAnchor[m_ui->m_detailsTab] = QString("details.search.details");
 
   // setup the register
@@ -191,7 +196,7 @@ KFindTransactionDlg::~KFindTransactionDlg()
   delete m_ui;
 }
 
-void KFindTransactionDlg::slotReset(void)
+void KFindTransactionDlg::slotReset()
 {
   m_ui->m_textEdit->setText(QString());
   m_ui->m_regExp->setChecked(false);
@@ -210,6 +215,9 @@ void KFindTransactionDlg::slotReset(void)
   m_ui->m_emptyPayeesButton->setChecked(false);
   selectAllItems(m_ui->m_payeesView, true);
 
+  m_ui->m_emptyTagsButton->setChecked(false);
+  selectAllItems(m_ui->m_tagsView, true);
+
   m_ui->m_typeBox->setCurrentIndex(MyMoneyTransactionFilter::allTypes);
   m_ui->m_stateBox->setCurrentIndex(MyMoneyTransactionFilter::allStates);
   m_ui->m_validityBox->setCurrentIndex(MyMoneyTransactionFilter::anyValidity);
@@ -232,7 +240,7 @@ void KFindTransactionDlg::slotReset(void)
   slotDateRangeChanged(MyMoneyTransactionFilter::allDates);
 }
 
-void KFindTransactionDlg::slotUpdateSelections(void)
+void KFindTransactionDlg::slotUpdateSelections()
 {
   QString txt;
 
@@ -278,6 +286,15 @@ void KFindTransactionDlg::slotUpdateSelections(void)
     txt += i18n("Category");
   }
 
+  // Tags tab
+  if (!allItemsSelected(m_ui->m_tagsView)
+      || m_ui->m_emptyTagsButton->isChecked()) {
+    if (!txt.isEmpty())
+      txt += ", ";
+    txt += i18n("Tags");
+  }
+  m_ui->m_tagsView->setEnabled(!m_ui->m_emptyTagsButton->isChecked());
+
   // Payees tab
   if (!allItemsSelected(m_ui->m_payeesView)
       || m_ui->m_emptyPayeesButton->isChecked()) {
@@ -312,7 +329,7 @@ void KFindTransactionDlg::slotUpdateSelections(void)
   if (txt.isEmpty()) {
     txt = i18nc("No selection", "(None)");
   }
-  m_ui->m_selectedCriteria->setText(i18n("Current selections: ") + txt);
+  m_ui->m_selectedCriteria->setText(i18n("Current selections: %1", txt));
 }
 
 bool KFindTransactionDlg::allItemsSelected(const QTreeWidgetItem *item) const
@@ -346,7 +363,7 @@ bool KFindTransactionDlg::allItemsSelected(const QTreeWidget* view) const
   return true;
 }
 
-void KFindTransactionDlg::setupAccountsPage(void)
+void KFindTransactionDlg::setupAccountsPage()
 {
   m_ui->m_accountsView->setSelectionMode(QTreeWidget::MultiSelection);
   AccountSet accountSet;
@@ -388,7 +405,7 @@ void KFindTransactionDlg::selectItems(QTreeWidget* view, const QStringList& list
   slotUpdateSelections();
 }
 
-void KFindTransactionDlg::setupCategoriesPage(void)
+void KFindTransactionDlg::setupCategoriesPage()
 {
   m_ui->m_categoriesView->setSelectionMode(QTreeWidget::MultiSelection);
   AccountSet categorySet;
@@ -422,7 +439,7 @@ void KFindTransactionDlg::selectSubItems(QTreeWidgetItem* item, const QStringLis
   }
 }
 
-void KFindTransactionDlg::setupDatePage(void)
+void KFindTransactionDlg::setupDatePage()
 {
   int i;
   for (i = MyMoneyTransactionFilter::allDates; i < MyMoneyTransactionFilter::dateOptionCount; ++i) {
@@ -452,7 +469,7 @@ void KFindTransactionDlg::slotDateRangeChanged(int idx)
   slotUpdateSelections();
 }
 
-void KFindTransactionDlg::slotDateChanged(void)
+void KFindTransactionDlg::slotDateChanged()
 {
   int idx;
   for (idx = MyMoneyTransactionFilter::asOfToday; idx < MyMoneyTransactionFilter::dateOptionCount; ++idx) {
@@ -471,7 +488,7 @@ void KFindTransactionDlg::slotDateChanged(void)
   slotUpdateSelections();
 }
 
-void KFindTransactionDlg::setupAmountPage(void)
+void KFindTransactionDlg::setupAmountPage()
 {
   connect(m_ui->m_amountButton, SIGNAL(clicked()), this, SLOT(slotAmountSelected()));
   connect(m_ui->m_amountRangeButton, SIGNAL(clicked()), this, SLOT(slotAmountRangeSelected()));
@@ -484,7 +501,7 @@ void KFindTransactionDlg::setupAmountPage(void)
   slotAmountSelected();
 }
 
-void KFindTransactionDlg::slotAmountSelected(void)
+void KFindTransactionDlg::slotAmountSelected()
 {
   m_ui->m_amountEdit->setEnabled(true);
   m_ui->m_amountFromEdit->setEnabled(false);
@@ -492,7 +509,7 @@ void KFindTransactionDlg::slotAmountSelected(void)
   slotUpdateSelections();
 }
 
-void KFindTransactionDlg::slotAmountRangeSelected(void)
+void KFindTransactionDlg::slotAmountRangeSelected()
 {
   m_ui->m_amountEdit->setEnabled(false);
   m_ui->m_amountFromEdit->setEnabled(true);
@@ -500,7 +517,7 @@ void KFindTransactionDlg::slotAmountRangeSelected(void)
   slotUpdateSelections();
 }
 
-void KFindTransactionDlg::setupPayeesPage(void)
+void KFindTransactionDlg::setupPayeesPage()
 {
   m_ui->m_payeesView->setSelectionMode(QAbstractItemView::SingleSelection);
   m_ui->m_payeesView->header()->hide();
@@ -517,7 +534,7 @@ void KFindTransactionDlg::setupPayeesPage(void)
   connect(m_ui->m_payeesView, SIGNAL(itemChanged(QTreeWidgetItem*,int)), this, SLOT(slotUpdateSelections()));
 }
 
-void KFindTransactionDlg::loadPayees(void)
+void KFindTransactionDlg::loadPayees()
 {
   MyMoneyFile* file = MyMoneyFile::instance();
   QList<MyMoneyPayee> list;
@@ -532,17 +549,59 @@ void KFindTransactionDlg::loadPayees(void)
     item->setCheckState(0, Qt::Checked);
   }
 }
-void KFindTransactionDlg::slotSelectAllPayees(void)
+void KFindTransactionDlg::slotSelectAllPayees()
 {
   selectAllItems(m_ui->m_payeesView, true);
 }
 
-void KFindTransactionDlg::slotDeselectAllPayees(void)
+void KFindTransactionDlg::slotDeselectAllPayees()
 {
   selectAllItems(m_ui->m_payeesView, false);
 }
 
-void KFindTransactionDlg::setupDetailsPage(void)
+void KFindTransactionDlg::setupTagsPage()
+{
+  m_ui->m_tagsView->setSelectionMode(QAbstractItemView::SingleSelection);
+  m_ui->m_tagsView->header()->hide();
+  m_ui->m_tagsView->setAlternatingRowColors(true);
+
+  loadTags();
+
+  m_ui->m_tagsView->sortItems(0, Qt::AscendingOrder);
+  m_ui->m_emptyTagsButton->setCheckState(Qt::Unchecked);
+
+  connect(m_ui->m_allTagsButton, SIGNAL(clicked()), this, SLOT(slotSelectAllTags()));
+  connect(m_ui->m_clearTagsButton, SIGNAL(clicked()), this, SLOT(slotDeselectAllTags()));
+  connect(m_ui->m_emptyTagsButton, SIGNAL(stateChanged(int)), this, SLOT(slotUpdateSelections()));
+  connect(m_ui->m_tagsView, SIGNAL(itemChanged(QTreeWidgetItem*,int)), this, SLOT(slotUpdateSelections()));
+}
+
+void KFindTransactionDlg::loadTags()
+{
+  MyMoneyFile* file = MyMoneyFile::instance();
+  QList<MyMoneyTag> list;
+  QList<MyMoneyTag>::Iterator it_l;
+
+  list = file->tagList();
+  // load view
+  for (it_l = list.begin(); it_l != list.end(); ++it_l) {
+    QTreeWidgetItem* item = new QTreeWidgetItem(m_ui->m_tagsView);
+    item->setText(0, (*it_l).name());
+    item->setData(0, ItemIdRole, (*it_l).id());
+    item->setCheckState(0, Qt::Checked);
+  }
+}
+void KFindTransactionDlg::slotSelectAllTags()
+{
+  selectAllItems(m_ui->m_tagsView, true);
+}
+
+void KFindTransactionDlg::slotDeselectAllTags()
+{
+  selectAllItems(m_ui->m_tagsView, false);
+}
+
+void KFindTransactionDlg::setupDetailsPage()
 {
   connect(m_ui->m_typeBox, SIGNAL(activated(int)), this, SLOT(slotUpdateSelections()));
   connect(m_ui->m_stateBox, SIGNAL(activated(int)), this, SLOT(slotUpdateSelections()));
@@ -558,7 +617,7 @@ void KFindTransactionDlg::setupDetailsPage(void)
   slotNrSelected();
 }
 
-void KFindTransactionDlg::slotNrSelected(void)
+void KFindTransactionDlg::slotNrSelected()
 {
   m_ui->m_nrEdit->setEnabled(true);
   m_ui->m_nrFromEdit->setEnabled(false);
@@ -566,7 +625,7 @@ void KFindTransactionDlg::slotNrSelected(void)
   slotUpdateSelections();
 }
 
-void KFindTransactionDlg::slotNrRangeSelected(void)
+void KFindTransactionDlg::slotNrRangeSelected()
 {
   m_ui->m_nrEdit->setEnabled(false);
   m_ui->m_nrFromEdit->setEnabled(true);
@@ -586,6 +645,9 @@ void KFindTransactionDlg::addItemToFilter(const opTypeE op, const QString& id)
     case addPayeeToFilter:
       m_filter.addPayee(id);
       break;
+    case addTagToFilter:
+      m_filter.addTag(id);
+      break;
   }
 }
 
@@ -620,7 +682,7 @@ void KFindTransactionDlg::scanCheckListItems(const QTreeWidget* view, const opTy
   }
 }
 
-void KFindTransactionDlg::setupFilter(void)
+void KFindTransactionDlg::setupFilter()
 {
   m_filter.clear();
 
@@ -684,6 +746,14 @@ void KFindTransactionDlg::setupFilter(void)
     m_filter.addCategory(m_ui->m_categoriesView->selectedItems());
   }
 
+  // Tags tab
+  if (m_ui->m_emptyTagsButton->isChecked()) {
+    m_filter.addTag(QString());
+
+  } else if (!allItemsSelected(m_ui->m_tagsView)) {
+    scanCheckListItems(m_ui->m_tagsView, addTagToFilter);
+  }
+
   // Payees tab
   if (m_ui->m_emptyPayeesButton->isChecked()) {
     m_filter.addPayee(QString());
@@ -711,7 +781,7 @@ void KFindTransactionDlg::setupFilter(void)
   }
 }
 
-void KFindTransactionDlg::slotSearch(void)
+void KFindTransactionDlg::slotSearch()
 {
   // perform the search only if the button is enabled
   if (!isButtonEnabled(KDialog::Apply))
@@ -726,7 +796,7 @@ void KFindTransactionDlg::slotSearch(void)
   m_ui->m_register->setFocus();
 }
 
-void KFindTransactionDlg::slotRefreshView(void)
+void KFindTransactionDlg::slotRefreshView()
 {
   m_needReload = true;
   if (isVisible()) {
@@ -744,7 +814,7 @@ void KFindTransactionDlg::showEvent(QShowEvent* event)
   KDialog::showEvent(event);
 }
 
-void KFindTransactionDlg::loadView(void)
+void KFindTransactionDlg::loadView()
 {
   // setup sort order
   m_ui->m_register->setSortOrder(KMyMoneyGlobalSettings::sortSearchView());
@@ -807,7 +877,7 @@ void KFindTransactionDlg::loadView(void)
   QTimer::singleShot(10, this, SLOT(slotRightSize()));
 }
 
-void KFindTransactionDlg::slotRightSize(void)
+void KFindTransactionDlg::slotRightSize()
 {
   m_ui->m_register->update();
 }
@@ -855,7 +925,7 @@ void KFindTransactionDlg::resizeEvent(QResizeEvent* ev)
 }
 
 
-void KFindTransactionDlg::slotSelectTransaction(void)
+void KFindTransactionDlg::slotSelectTransaction()
 {
   QList<KMyMoneyRegister::RegisterItem*> list = m_ui->m_register->selectedItems();
   if (!list.isEmpty()) {
@@ -892,7 +962,7 @@ bool KFindTransactionDlg::eventFilter(QObject* o, QEvent* e)
   return rc;
 }
 
-void KFindTransactionDlg::slotShowHelp(void)
+void KFindTransactionDlg::slotShowHelp()
 {
   QString anchor = m_helpAnchor[m_ui->m_criteriaTab->currentWidget()];
   if (anchor.isEmpty())
@@ -901,7 +971,7 @@ void KFindTransactionDlg::slotShowHelp(void)
   KToolInvocation::invokeHelp(anchor);
 }
 
-void KFindTransactionDlg::slotSortOptions(void)
+void KFindTransactionDlg::slotSortOptions()
 {
   QPointer<KSortOptionDlg> dlg = new KSortOptionDlg(this);
 
@@ -917,9 +987,3 @@ void KFindTransactionDlg::slotSortOptions(void)
   }
   delete dlg;
 }
-
-
-// vim:cin:si:ai:et:ts=2:sw=2:
-
-
-#include "kfindtransactiondlg.moc"
