@@ -214,6 +214,11 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
 
   bool haveMinBalance = false;
   bool haveMaxCredit = false;
+  if (!m_account.openingDate().isValid()) {
+    m_account.setOpeningDate(KMyMoneyGlobalSettings::firstFiscalDate());
+  }
+  m_openingDateEdit->setDate(m_account.openingDate());
+
   if (categoryEditor) {
     // get rid of the tabs that are not used for categories
     int tab = m_tab->indexOf(m_institutionTab);
@@ -224,7 +229,6 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
       m_tab->removeTab(tab);
 
     //m_qlistviewParentAccounts->setEnabled(true);
-    startDateEdit->setEnabled(false);
     accountNoEdit->setEnabled(false);
 
     m_institutionBox->hide();
@@ -349,10 +353,6 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
     if (account.isInvest())
       m_institutionBox->hide();
 
-    if (!m_account.openingDate().isValid())
-      m_account.setOpeningDate(QDate::currentDate());
-
-    startDateEdit->setDate(m_account.openingDate());
     accountNoEdit->setText(account.number());
     m_qcheckboxPreferred->setChecked(account.value("PreferredAccount") == "Yes");
     m_qcheckboxNoVat->setChecked(account.value("NoVat") == "Yes");
@@ -363,9 +363,9 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
     loadKVP("maxCreditEarly", m_maxCreditEarlyEdit);
     // reverse the sign for display purposes
     if (!m_maxCreditAbsoluteEdit->lineedit()->text().isEmpty())
-      m_maxCreditAbsoluteEdit->setValue(m_maxCreditAbsoluteEdit->value()*MyMoneyMoney(-1, 1));
+      m_maxCreditAbsoluteEdit->setValue(m_maxCreditAbsoluteEdit->value()*MyMoneyMoney::MINUS_ONE);
     if (!m_maxCreditEarlyEdit->lineedit()->text().isEmpty())
-      m_maxCreditEarlyEdit->setValue(m_maxCreditEarlyEdit->value()*MyMoneyMoney(-1, 1));
+      m_maxCreditEarlyEdit->setValue(m_maxCreditEarlyEdit->value()*MyMoneyMoney::MINUS_ONE);
     loadKVP("lastNumberUsed", m_lastCheckNumberUsed);
 
     if (m_account.isInvest()) {
@@ -494,6 +494,12 @@ void KNewAccountDlg::setOpeningBalanceShown(bool shown)
   m_openingBalanceEdit->setVisible(shown);
 }
 
+void KNewAccountDlg::setOpeningDateShown(bool shown)
+{
+  m_openingDateLabel->setVisible(shown);
+  m_openingDateEdit->setVisible(shown);
+}
+
 void KNewAccountDlg::okClicked()
 {
   MyMoneyFile* file = MyMoneyFile::instance();
@@ -539,15 +545,15 @@ void KNewAccountDlg::okClicked()
 
   // the figures for credit line with reversed sign
   if (!m_maxCreditAbsoluteEdit->lineedit()->text().isEmpty())
-    m_maxCreditAbsoluteEdit->setValue(m_maxCreditAbsoluteEdit->value()*MyMoneyMoney(-1, 1));
+    m_maxCreditAbsoluteEdit->setValue(m_maxCreditAbsoluteEdit->value()*MyMoneyMoney::MINUS_ONE);
   if (!m_maxCreditEarlyEdit->lineedit()->text().isEmpty())
-    m_maxCreditEarlyEdit->setValue(m_maxCreditEarlyEdit->value()*MyMoneyMoney(-1, 1));
+    m_maxCreditEarlyEdit->setValue(m_maxCreditEarlyEdit->value()*MyMoneyMoney::MINUS_ONE);
   storeKVP("maxCreditAbsolute", m_maxCreditAbsoluteEdit);
   storeKVP("maxCreditEarly", m_maxCreditEarlyEdit);
   if (!m_maxCreditAbsoluteEdit->lineedit()->text().isEmpty())
-    m_maxCreditAbsoluteEdit->setValue(m_maxCreditAbsoluteEdit->value()*MyMoneyMoney(-1, 1));
+    m_maxCreditAbsoluteEdit->setValue(m_maxCreditAbsoluteEdit->value()*MyMoneyMoney::MINUS_ONE);
   if (!m_maxCreditEarlyEdit->lineedit()->text().isEmpty())
-    m_maxCreditEarlyEdit->setValue(m_maxCreditEarlyEdit->value()*MyMoneyMoney(-1, 1));
+    m_maxCreditEarlyEdit->setValue(m_maxCreditEarlyEdit->value()*MyMoneyMoney::MINUS_ONE);
 
   storeKVP("lastNumberUsed", m_lastCheckNumberUsed);
   // delete a previous version of the minimumbalance information
@@ -578,8 +584,9 @@ void KNewAccountDlg::okClicked()
 
   m_account.setDescription(descriptionEdit->toPlainText());
 
+  m_account.setOpeningDate(m_openingDateEdit->date());
+
   if (!m_categoryEditor) {
-    m_account.setOpeningDate(startDateEdit->date());
     m_account.setCurrencyId(m_currency->security().id());
 
     if (m_qcheckboxPreferred->isChecked())
@@ -660,7 +667,7 @@ void KNewAccountDlg::storeKVP(const QString& key, KLineEdit* widget)
   storeKVP(key, widget->text(), widget->text());
 }
 
-const MyMoneyAccount& KNewAccountDlg::account(void)
+const MyMoneyAccount& KNewAccountDlg::account()
 {
   // assign the right currency to the account
   m_account.setCurrencyId(m_currency->security().id());
@@ -679,7 +686,7 @@ const MyMoneyAccount& KNewAccountDlg::account(void)
   return m_account;
 }
 
-const MyMoneyAccount& KNewAccountDlg::parentAccount(void)
+const MyMoneyAccount& KNewAccountDlg::parentAccount()
 {
   return m_parentAccount;
 }
@@ -696,7 +703,7 @@ void KNewAccountDlg::slotSelectionChanged(const QItemSelection &current, const Q
   }
 }
 
-void KNewAccountDlg::loadVatAccounts(void)
+void KNewAccountDlg::loadVatAccounts()
 {
   QList<MyMoneyAccount> list;
   MyMoneyFile::instance()->accountList(list);
@@ -797,7 +804,7 @@ void KNewAccountDlg::slotAccountTypeChanged(const QString& typeStr)
   }
 }
 
-void KNewAccountDlg::slotCheckFinished(void)
+void KNewAccountDlg::slotCheckFinished()
 {
   bool showButton = true;
 
