@@ -23,6 +23,8 @@
 
 #include <QtTest/QtTest>
 
+#include <config-kmymoney.h>
+
 #define KMM_MYMONEY_UNIT_TESTABLE friend class MyMoneyMoneyTest;
 
 // Check for standard definitions
@@ -237,11 +239,7 @@ void MyMoneyMoneyTest::testStringConstructor()
   delete m1;
 
   m1 = new MyMoneyMoney("09");
-  // this is tricky: using libalkimia 4.3.1 returns 0 here
-  // and newer version return 0. Since we cannot determine
-  // the version of the library used here, we check against
-  // both values
-  QVERIFY((m1->valueRef().get_num() == 0) || (m1->valueRef().get_num() == 9));
+  QVERIFY(m1->valueRef().get_num() == (9));
   QVERIFY(m1->valueRef().get_den() == 1);
   delete m1;
 }
@@ -570,7 +568,9 @@ void MyMoneyMoneyTest::testDoubleConstructor()
     MyMoneyMoney r(i, 100);
     d /= 100;
     MyMoneyMoney t(d, 100);
+    MyMoneyMoney s(i);
     QVERIFY(t == r);
+    QVERIFY(i == s.toDouble());
   }
 }
 
@@ -601,7 +601,7 @@ void MyMoneyMoneyTest::testToString()
   //QVERIFY(m3.toString() == QString("0"));
 }
 
-void MyMoneyMoneyTest::testNegativeSignPos(void)
+void MyMoneyMoneyTest::testNegativeSignPos()
 {
   MyMoneyMoney m("-123456/100");
 
@@ -634,7 +634,7 @@ void MyMoneyMoneyTest::testNegativeSignPos(void)
   MyMoneyMoney::setNegativeMonetarySignPosition(pos);
 }
 
-void MyMoneyMoneyTest::testPositiveSignPos(void)
+void MyMoneyMoneyTest::testPositiveSignPos()
 {
   MyMoneyMoney m("123456/100");
 
@@ -667,7 +667,7 @@ void MyMoneyMoneyTest::testPositiveSignPos(void)
   MyMoneyMoney::setPositiveMonetarySignPosition(pos);
 }
 
-void MyMoneyMoneyTest::testNegativeStringConstructor(void)
+void MyMoneyMoneyTest::testNegativeStringConstructor()
 {
   MyMoneyMoney *m1;
   MyMoneyMoney::setDecimalSeparator(',');
@@ -698,7 +698,7 @@ void MyMoneyMoneyTest::testNegativeStringConstructor(void)
   delete m1;
 }
 
-void MyMoneyMoneyTest::testReduce(void)
+void MyMoneyMoneyTest::testReduce()
 {
   MyMoneyMoney a(36488100, 1267390000);
   MyMoneyMoney b(-a);
@@ -717,17 +717,12 @@ void MyMoneyMoneyTest::testZeroDenominator()
   try {
     MyMoneyMoney m((int)1, 0);
     QFAIL("Missing expected exception");
-  } catch (MyMoneyException *e) {
-    delete e;
+  } catch (const MyMoneyException &) {
   }
 
   try {
     MyMoneyMoney m((signed64)1, 0);
     QFAIL("Missing expected exception");
-  } catch (MyMoneyException *e) {
-    delete e;
+  } catch (const MyMoneyException &) {
   }
 }
-
-#include "mymoneymoneytest.moc"
-
