@@ -44,27 +44,27 @@ MyMoneyDatabaseMgr::~MyMoneyDatabaseMgr()
 { }
 
 // general get functions
-const MyMoneyPayee MyMoneyDatabaseMgr::user(void) const
+const MyMoneyPayee& MyMoneyDatabaseMgr::user() const
 {
   return m_user;
 }
 
-const QDate MyMoneyDatabaseMgr::creationDate(void) const
+const QDate MyMoneyDatabaseMgr::creationDate() const
 {
   return m_creationDate;
 }
 
-const QDate MyMoneyDatabaseMgr::lastModificationDate(void) const
+const QDate MyMoneyDatabaseMgr::lastModificationDate() const
 {
   return m_lastModificationDate;
 }
 
-unsigned int MyMoneyDatabaseMgr::currentFixVersion(void) const
+unsigned int MyMoneyDatabaseMgr::currentFixVersion() const
 {
   return CURRENT_FIX_VERSION;
 }
 
-unsigned int MyMoneyDatabaseMgr::fileFixVersion(void) const
+unsigned int MyMoneyDatabaseMgr::fileFixVersion() const
 {
   return m_fileFixVersion;
 }
@@ -100,7 +100,7 @@ void MyMoneyDatabaseMgr::deletePair(const QString& key)
   MyMoneyKeyValueContainer::deletePair(key);
 }
 
-const QMap<QString, QString> MyMoneyDatabaseMgr::pairs(void) const
+const QMap<QString, QString> MyMoneyDatabaseMgr::pairs() const
 {
   return MyMoneyKeyValueContainer::pairs();
 }
@@ -110,7 +110,7 @@ void MyMoneyDatabaseMgr::setPairs(const QMap<QString, QString>& list)
   MyMoneyKeyValueContainer::setPairs(list);
 }
 
-MyMoneyDatabaseMgr const * MyMoneyDatabaseMgr::duplicate(void)
+MyMoneyDatabaseMgr const * MyMoneyDatabaseMgr::duplicate()
 {
   MyMoneyDatabaseMgr* that = new MyMoneyDatabaseMgr();
   *that = *this;
@@ -175,7 +175,8 @@ void MyMoneyDatabaseMgr::addAccount(MyMoneyAccount& parent, MyMoneyAccount& acco
 void MyMoneyDatabaseMgr::addPayee(MyMoneyPayee& payee)
 {
   if (m_sql) {
-    if (! m_sql->isOpen())((QSqlDatabase*)(m_sql.data()))->open();
+    if (! m_sql->isOpen())
+      static_cast<QSqlDatabase*>(m_sql.data())->open();
     // create the payee
     MyMoneyPayee newPayee(nextPayeeID(), payee);
 
@@ -268,7 +269,7 @@ void MyMoneyDatabaseMgr::removePayee(const MyMoneyPayee& payee)
   m_sql->removePayee(payee);
 }
 
-const QList<MyMoneyPayee> MyMoneyDatabaseMgr::payeeList(void) const
+const QList<MyMoneyPayee> MyMoneyDatabaseMgr::payeeList() const
 {
   if (m_sql) {
     if (! m_sql->isOpen())((QSqlDatabase*)(m_sql.data()))->open();
@@ -373,13 +374,68 @@ void MyMoneyDatabaseMgr::removeTag(const MyMoneyTag& tag)
   m_sql->removeTag(tag);
 }
 
-const QList<MyMoneyTag> MyMoneyDatabaseMgr::tagList(void) const
+const QList<MyMoneyTag> MyMoneyDatabaseMgr::tagList() const
 {
   if (m_sql) {
     if (! m_sql->isOpen())((QSqlDatabase*)(m_sql.data()))->open();
     return m_sql->fetchTags().values();
-  } else
+  } else {
     return QList<MyMoneyTag> ();
+  }
+}
+
+void MyMoneyDatabaseMgr::modifyOnlineJob(const onlineJob& job)
+{
+  if (job.id().isEmpty())
+    throw MYMONEYEXCEPTION("empty online job id");
+  m_sql->modifyOnlineJob(job);
+}
+
+void MyMoneyDatabaseMgr::addOnlineJob(onlineJob& job)
+{
+  job = onlineJob(nextOnlineJobID(), job);
+  m_sql->addOnlineJob(job);
+}
+
+const onlineJob MyMoneyDatabaseMgr::getOnlineJob(const QString &jobId) const
+{
+  if (jobId.isEmpty())
+    throw MYMONEYEXCEPTION("empty online job id");
+
+  if (m_sql) {
+    if (! m_sql->isOpen())
+      ((QSqlDatabase*)(m_sql.data()))->open();
+
+    QMap <QString, onlineJob> jobList = m_sql->fetchOnlineJobs(QStringList(jobId));
+    QMap <QString, onlineJob>::ConstIterator pos = jobList.constFind(jobId);
+
+    // locate the account and if present, return it's data
+    if (pos != jobList.constEnd())
+      return *pos;
+  } else {
+    throw MYMONEYEXCEPTION("No database connected");
+  }
+
+  // throw an exception, if it does not exist
+  throw MYMONEYEXCEPTION(QLatin1String("Unknown online job id '") + jobId + QLatin1Char('\''));
+}
+
+const QList<onlineJob> MyMoneyDatabaseMgr::onlineJobList() const
+{
+  if (m_sql) {
+    if (!m_sql->isOpen())
+      ((QSqlDatabase*)(m_sql.data()))->open();
+    return m_sql->fetchOnlineJobs().values();
+  }
+  return QList<onlineJob>();
+}
+
+void MyMoneyDatabaseMgr::removeOnlineJob(const onlineJob& job)
+{
+  if (job.id().isEmpty())
+    throw MYMONEYEXCEPTION("Empty online job id during remove.");
+
+  m_sql->removeOnlineJob(job);
 }
 
 const MyMoneyAccount MyMoneyDatabaseMgr::account(const QString& id) const
@@ -443,7 +499,7 @@ void MyMoneyDatabaseMgr::addInstitution(MyMoneyInstitution& institution)
   }
 }
 
-const QString MyMoneyDatabaseMgr::nextPayeeID(void)
+const QString MyMoneyDatabaseMgr::nextPayeeID()
 {
   QString id;
   if (m_sql) {
@@ -454,7 +510,7 @@ const QString MyMoneyDatabaseMgr::nextPayeeID(void)
   return id;
 }
 
-const QString MyMoneyDatabaseMgr::nextTagID(void)
+const QString MyMoneyDatabaseMgr::nextTagID()
 {
   QString id;
   if (m_sql) {
@@ -465,7 +521,7 @@ const QString MyMoneyDatabaseMgr::nextTagID(void)
   return id;
 }
 
-const QString MyMoneyDatabaseMgr::nextInstitutionID(void)
+const QString MyMoneyDatabaseMgr::nextInstitutionID()
 {
   QString id;
   if (m_sql) {
@@ -476,7 +532,7 @@ const QString MyMoneyDatabaseMgr::nextInstitutionID(void)
   return id;
 }
 
-const QString MyMoneyDatabaseMgr::nextAccountID(void)
+const QString MyMoneyDatabaseMgr::nextAccountID()
 {
   QString id;
   if (m_sql) {
@@ -487,7 +543,7 @@ const QString MyMoneyDatabaseMgr::nextAccountID(void)
   return id;
 }
 
-const QString MyMoneyDatabaseMgr::nextBudgetID(void)
+const QString MyMoneyDatabaseMgr::nextBudgetID()
 {
   QString id;
   if (m_sql) {
@@ -498,7 +554,7 @@ const QString MyMoneyDatabaseMgr::nextBudgetID(void)
   return id;
 }
 
-const QString MyMoneyDatabaseMgr::nextReportID(void)
+const QString MyMoneyDatabaseMgr::nextReportID()
 {
   QString id;
   if (m_sql) {
@@ -509,7 +565,7 @@ const QString MyMoneyDatabaseMgr::nextReportID(void)
   return id;
 }
 
-const QString MyMoneyDatabaseMgr::nextTransactionID(void)
+const QString MyMoneyDatabaseMgr::nextTransactionID()
 {
   QString id;
   if (m_sql) {
@@ -520,7 +576,7 @@ const QString MyMoneyDatabaseMgr::nextTransactionID(void)
   return id;
 }
 
-const QString MyMoneyDatabaseMgr::nextScheduleID(void)
+const QString MyMoneyDatabaseMgr::nextScheduleID()
 {
   QString id;
   if (m_sql) {
@@ -531,7 +587,7 @@ const QString MyMoneyDatabaseMgr::nextScheduleID(void)
   return id;
 }
 
-const QString MyMoneyDatabaseMgr::nextSecurityID(void)
+const QString MyMoneyDatabaseMgr::nextSecurityID()
 {
   QString id;
   if (m_sql) {
@@ -542,6 +598,28 @@ const QString MyMoneyDatabaseMgr::nextSecurityID(void)
   return id;
 }
 
+const QString MyMoneyDatabaseMgr::nextOnlineJobID()
+{
+  QString id;
+  if (m_sql) {
+    if (! m_sql->isOpen())((QSqlDatabase*)(m_sql.data()))->open();
+    id.setNum(m_sql->incrementOnlineJobId());
+    id = QLatin1Char('O') + id.rightJustified(ONLINEJOB_ID_SIZE, '0');
+  }
+  return id;
+}
+
+const QString MyMoneyDatabaseMgr::nextPayeeIdentifierID()
+{
+  QString id;
+  if (m_sql) {
+    if (! m_sql->isOpen())((QSqlDatabase*)(m_sql.data()))->open();
+    id.setNum(m_sql->incrementPayeeIdentfierId());
+    id = QLatin1String("IDENT") + id.rightJustified(PAYEEIDENTIFIER_ID_SIZE, '0');
+  }
+  return id;
+}
+
 void MyMoneyDatabaseMgr::addTransaction(MyMoneyTransaction& transaction, const bool skipAccountUpdate)
 {
   // perform some checks to see that the transaction stuff is OK. For
@@ -653,20 +731,20 @@ const MyMoneyInstitution MyMoneyDatabaseMgr::institution(const QString& id) cons
   throw MYMONEYEXCEPTION("unknown institution");
 }
 
-bool MyMoneyDatabaseMgr::dirty(void) const
+bool MyMoneyDatabaseMgr::dirty() const
 {
   return false;
 }
 
-void MyMoneyDatabaseMgr::setDirty(void)
+void MyMoneyDatabaseMgr::setDirty()
 {}
 
-unsigned int MyMoneyDatabaseMgr::accountCount(void) const
+unsigned int MyMoneyDatabaseMgr::accountCount() const
 {
   return m_sql->getRecCount("kmmAccounts");
 }
 
-const QList<MyMoneyInstitution> MyMoneyDatabaseMgr::institutionList(void) const
+const QList<MyMoneyInstitution> MyMoneyDatabaseMgr::institutionList() const
 {
   if (m_sql) {
     if (! m_sql->isOpen())((QSqlDatabase*)(m_sql.data()))->open();
@@ -926,7 +1004,7 @@ unsigned int MyMoneyDatabaseMgr::transactionCount(const QString& account) const
   return (m_sql->transactionCount(account));
 }
 
-const QMap<QString, unsigned long> MyMoneyDatabaseMgr::transactionCountMap(void) const
+const QMap<QString, unsigned long> MyMoneyDatabaseMgr::transactionCountMap() const
 {
 
   QMap<QString, unsigned long> retval;
@@ -1216,7 +1294,7 @@ const MyMoneyTransaction MyMoneyDatabaseMgr::transaction(const QString& account,
   return transaction(list[idx].id());
 }
 
-unsigned int MyMoneyDatabaseMgr::institutionCount(void) const
+unsigned int MyMoneyDatabaseMgr::institutionCount() const
 {
   return m_sql->getRecCount("kmmInstitutions");
 }
@@ -1237,27 +1315,27 @@ void MyMoneyDatabaseMgr::accountList(QList<MyMoneyAccount>& list) const
   }
 }
 
-const MyMoneyAccount MyMoneyDatabaseMgr::liability(void) const
+const MyMoneyAccount MyMoneyDatabaseMgr::liability() const
 {
   return MyMoneyFile::instance()->account(STD_ACC_LIABILITY);
 }
 
-const MyMoneyAccount MyMoneyDatabaseMgr::asset(void) const
+const MyMoneyAccount MyMoneyDatabaseMgr::asset() const
 {
   return MyMoneyFile::instance()->account(STD_ACC_ASSET);
 }
 
-const MyMoneyAccount MyMoneyDatabaseMgr::expense(void) const
+const MyMoneyAccount MyMoneyDatabaseMgr::expense() const
 {
   return MyMoneyFile::instance()->account(STD_ACC_EXPENSE);
 }
 
-const MyMoneyAccount MyMoneyDatabaseMgr::income(void) const
+const MyMoneyAccount MyMoneyDatabaseMgr::income() const
 {
   return MyMoneyFile::instance()->account(STD_ACC_INCOME);
 }
 
-const MyMoneyAccount MyMoneyDatabaseMgr::equity(void) const
+const MyMoneyAccount MyMoneyDatabaseMgr::equity() const
 {
   return MyMoneyFile::instance()->account(STD_ACC_EQUITY);
 }
@@ -1321,7 +1399,7 @@ const MyMoneySecurity MyMoneyDatabaseMgr::security(const QString& id) const
   return MyMoneySecurity();
 }
 
-const QList<MyMoneySecurity> MyMoneyDatabaseMgr::securityList(void) const
+const QList<MyMoneySecurity> MyMoneyDatabaseMgr::securityList() const
 {
   return m_sql->fetchSecurities().values();
 }
@@ -1346,12 +1424,12 @@ void MyMoneyDatabaseMgr::removePrice(const MyMoneyPrice& price)
   m_sql->removePrice(price);
 }
 
-const MyMoneyPrice MyMoneyDatabaseMgr::price(const QString& fromId, const QString& toId, const QDate& _date, const bool exactDate) const
+MyMoneyPrice MyMoneyDatabaseMgr::price(const QString& fromId, const QString& toId, const QDate& _date, const bool exactDate) const
 {
   return m_sql->fetchSinglePrice(fromId, toId, _date, exactDate);
 }
 
-const MyMoneyPriceList MyMoneyDatabaseMgr::priceList(void) const
+const MyMoneyPriceList MyMoneyDatabaseMgr::priceList() const
 {
   return m_sql->fetchPrices();
 }
@@ -1619,7 +1697,7 @@ const MyMoneySecurity MyMoneyDatabaseMgr::currency(const QString& id) const
   return *it;
 }
 
-const QList<MyMoneySecurity> MyMoneyDatabaseMgr::currencyList(void) const
+const QList<MyMoneySecurity> MyMoneyDatabaseMgr::currencyList() const
 {
   if (m_sql) {
     if (! m_sql->isOpen())((QSqlDatabase*)(m_sql.data()))->open();
@@ -1629,7 +1707,7 @@ const QList<MyMoneySecurity> MyMoneyDatabaseMgr::currencyList(void) const
   }
 }
 
-const QList<MyMoneyReport> MyMoneyDatabaseMgr::reportList(void) const
+const QList<MyMoneyReport> MyMoneyDatabaseMgr::reportList() const
 {
   if (m_sql) {
     if (! m_sql->isOpen())((QSqlDatabase*)(m_sql.data()))->open();
@@ -1661,7 +1739,7 @@ void MyMoneyDatabaseMgr::modifyReport(const MyMoneyReport& report)
   m_sql->modifyReport(report);
 }
 
-unsigned MyMoneyDatabaseMgr::countReports(void) const
+unsigned MyMoneyDatabaseMgr::countReports() const
 {
   return m_sql->getRecCount("kmmReports");
 }
@@ -1685,7 +1763,7 @@ void MyMoneyDatabaseMgr::removeReport(const MyMoneyReport& report)
   m_sql->removeReport(report);
 }
 
-const QList<MyMoneyBudget> MyMoneyDatabaseMgr::budgetList(void) const
+const QList<MyMoneyBudget> MyMoneyDatabaseMgr::budgetList() const
 {
   return m_sql->fetchBudgets().values();
 }
@@ -1730,7 +1808,7 @@ void MyMoneyDatabaseMgr::modifyBudget(const MyMoneyBudget& budget)
   commitTransaction();
 }
 
-unsigned MyMoneyDatabaseMgr::countBudgets(void) const
+unsigned MyMoneyDatabaseMgr::countBudgets() const
 {
   return m_sql->getRecCount("kmmBudgetConfig");
 }
@@ -1753,7 +1831,7 @@ void MyMoneyDatabaseMgr::removeBudget(const MyMoneyBudget& budget)
   m_sql->removeBudget(budget);
 }
 
-void MyMoneyDatabaseMgr::clearCache(void)
+void MyMoneyDatabaseMgr::clearCache()
 {
   //m_balanceCache.clear();
 }
@@ -1861,7 +1939,7 @@ bool MyMoneyDatabaseMgr::isReferenced(const MyMoneyObject& obj, const MyMoneyFil
   return rc;
 }
 
-void MyMoneyDatabaseMgr::close(void)
+void MyMoneyDatabaseMgr::close()
 {
   if (m_sql) {
     m_sql->close(true);
@@ -1869,7 +1947,7 @@ void MyMoneyDatabaseMgr::close(void)
   }
 }
 
-void MyMoneyDatabaseMgr::startTransaction(void)
+void MyMoneyDatabaseMgr::startTransaction()
 {
   if (m_sql) {
     if (! m_sql->isOpen())((QSqlDatabase*)(m_sql.data()))->open();
@@ -1877,7 +1955,7 @@ void MyMoneyDatabaseMgr::startTransaction(void)
   }
 }
 
-bool MyMoneyDatabaseMgr::commitTransaction(void)
+bool MyMoneyDatabaseMgr::commitTransaction()
 {
   if (m_sql) {
     if (! m_sql->isOpen())((QSqlDatabase*)(m_sql.data()))->open();
@@ -1886,7 +1964,7 @@ bool MyMoneyDatabaseMgr::commitTransaction(void)
   return false;
 }
 
-void MyMoneyDatabaseMgr::rollbackTransaction(void)
+void MyMoneyDatabaseMgr::rollbackTransaction()
 {
   if (m_sql) {
     if (! m_sql->isOpen())((QSqlDatabase*)(m_sql.data()))->open();
@@ -2023,49 +2101,64 @@ void MyMoneyDatabaseMgr::loadPrices(const MyMoneyPriceList& list)
   Q_UNUSED(list);
 }
 
-unsigned long MyMoneyDatabaseMgr::accountId(void) const
+void MyMoneyDatabaseMgr::loadOnlineJobs(const QMap< QString, onlineJob >& onlineJobs)
 {
-  return m_sql->getNextAccountId();
+  Q_UNUSED(onlineJobs);
 }
 
-unsigned long MyMoneyDatabaseMgr::transactionId(void) const
+unsigned long MyMoneyDatabaseMgr::accountId() const
 {
-  return m_sql->getNextTransactionId();
+  return m_sql->getNextAccountId() - 1;
 }
 
-unsigned long MyMoneyDatabaseMgr::payeeId(void) const
+unsigned long MyMoneyDatabaseMgr::transactionId() const
 {
-  return m_sql->getNextPayeeId();
+  return m_sql->getNextTransactionId() - 1;
 }
 
-unsigned long MyMoneyDatabaseMgr::tagId(void) const
+unsigned long MyMoneyDatabaseMgr::payeeId() const
 {
-  return m_sql->getNextTagId();
+  return m_sql->getNextPayeeId() - 1;
 }
 
-unsigned long MyMoneyDatabaseMgr::institutionId(void) const
+unsigned long MyMoneyDatabaseMgr::tagId() const
 {
-  return m_sql->getNextInstitutionId();
+  return m_sql->getNextTagId() - 1;
 }
 
-unsigned long MyMoneyDatabaseMgr::scheduleId(void) const
+unsigned long MyMoneyDatabaseMgr::institutionId() const
 {
-  return m_sql->getNextScheduleId();
+  return m_sql->getNextInstitutionId() - 1;
 }
 
-unsigned long MyMoneyDatabaseMgr::securityId(void) const
+unsigned long MyMoneyDatabaseMgr::scheduleId() const
 {
-  return m_sql->getNextSecurityId();
+  return m_sql->getNextScheduleId() - 1;
 }
 
-unsigned long MyMoneyDatabaseMgr::reportId(void) const
+unsigned long MyMoneyDatabaseMgr::securityId() const
 {
-  return m_sql->getNextReportId();
+  return m_sql->getNextSecurityId() - 1;
 }
 
-unsigned long MyMoneyDatabaseMgr::budgetId(void) const
+unsigned long MyMoneyDatabaseMgr::reportId() const
 {
-  return m_sql->getNextBudgetId();
+  return m_sql->getNextReportId() - 1;
+}
+
+unsigned long MyMoneyDatabaseMgr::budgetId() const
+{
+  return m_sql->getNextBudgetId() - 1;
+}
+
+long unsigned int MyMoneyDatabaseMgr::onlineJobId() const
+{
+  return m_sql->getNextOnlineJobId() - 1;
+}
+
+long unsigned int MyMoneyDatabaseMgr::payeeIdentifierId() const
+{
+  return m_sql->getNextPayeeIdentifierId() - 1;
 }
 
 void MyMoneyDatabaseMgr::loadAccountId(const unsigned long id)
@@ -2113,7 +2206,17 @@ void MyMoneyDatabaseMgr::loadBudgetId(const unsigned long id)
   m_sql->loadBudgetId(id);
 }
 
-void MyMoneyDatabaseMgr::rebuildAccountBalances(void)
+void MyMoneyDatabaseMgr::loadOnlineJobId(const long unsigned int id)
+{
+  m_sql->loadOnlineJobId(id);
+}
+
+void MyMoneyDatabaseMgr::loadPayeeIdentifierId(const long unsigned int id)
+{
+  m_sql->loadPayeeIdentifierId(id);
+}
+
+void MyMoneyDatabaseMgr::rebuildAccountBalances()
 {
   startTransaction();
   QMap<QString, MyMoneyAccount> accountMap = m_sql->fetchAccounts(QStringList(), true);
