@@ -158,6 +158,11 @@ public:
    */
   virtual const QString tableOptionString() const;
 
+  /**
+   * @return The SQL string to find the highest ID number with an arbitrary prefix
+   */
+  virtual const QString highestNumberFromIdString(const QString& tableName, const QString& tableField, const int prefixLength) const;
+
   /**
    * Override standard tables() call for bug 252841
    */
