@@ -49,11 +49,6 @@
 
 using namespace reports;
 
-// the percent from the height of the widget which will be set as the maximum height of the legend
-// note that this will work as long as we have the legend positioned at Position::East
-static const qreal LEGEND_HEIGHT_PERCENT = 0.8;
-static const qreal LEGEND_WIDTH_PERCENT = 0.2;
-
 KReportChartView::KReportChartView(QWidget* parent) :
     KDChart::Chart(parent),
     m_backgroundBrush(KColorScheme(QPalette::Current).background()),
@@ -79,7 +74,6 @@ KReportChartView::KReportChartView(QWidget* parent) :
 
 void KReportChartView::drawPivotChart(const PivotGrid &grid, const MyMoneyReport &config, int numberColumns, const QStringList& columnHeadings, const QList<ERowType>& rowTypeList, const QStringList& columnTypeHeaderList)
 {
-  ::timetrace("start drawing chart");
   //set the number of columns
   setNumColumns(numberColumns);
 
@@ -261,7 +255,6 @@ void KReportChartView::drawPivotChart(const PivotGrid &grid, const MyMoneyReport
     }
   }
 
-  ::timetrace("loading rows");
   switch (config.detailLevel()) {
     case MyMoneyReport::eDetailNone:
     case MyMoneyReport::eDetailEnd:
@@ -442,7 +435,6 @@ void KReportChartView::drawPivotChart(const PivotGrid &grid, const MyMoneyReport
       }
       break;
   }
-  ::timetrace("rows loaded");
 
   //assign model to the diagram
   planeDiagram->setModel(&m_model);
@@ -452,31 +444,34 @@ void KReportChartView::drawPivotChart(const PivotGrid &grid, const MyMoneyReport
   for (uint i = static_cast<uint>(KMyMoneyGlobalSettings::maximumLegendItems()); i < legend->datasetCount(); ++i) {
     legend->setDatasetHidden(i, true);
   }
-  legend->setPosition(Position::East);
-  TextAttributes legendTextAttr(legend->textAttributes());
-  legendTextAttr.setFontSize(KGlobalSettings::generalFont().pointSize() + 2);
-  legendTextAttr.setAutoShrink(true);
-  legendTextAttr.setPen(m_foregroundBrush.color());
-  legend->setTextAttributes(legendTextAttr);
-
-  TextAttributes legendTitleTextAttr(legend->titleTextAttributes());
-  legendTitleTextAttr.setFontSize(KGlobalSettings::generalFont().pointSize() + 4);
-  legendTitleTextAttr.setAutoShrink(true);
-  legendTitleTextAttr.setPen(m_foregroundBrush.color());
-  legend->setTitleTextAttributes(legendTitleTextAttr);
   legend->setTitleText(i18nc("Chart lines legend", "Legend"));
   legend->setUseAutomaticMarkerSize(false);
   FrameAttributes legendFrameAttr(legend->frameAttributes());
   legendFrameAttr.setPen(m_foregroundBrush.color());
+  // leave some space between the content and the frame
+  legendFrameAttr.setPadding(2);
   legend->setFrameAttributes(legendFrameAttr);
-  // see also KReportChartView::resizeEvent
-  legend->setMaximumHeight(height() * LEGEND_HEIGHT_PERCENT);
-  legend->setMaximumWidth(width() * LEGEND_WIDTH_PERCENT);
+  legend->setPosition(Position::East);
+  legend->setTextAlignment(Qt::AlignLeft);
+  legend->setLegendStyle(KDChart::Legend::MarkersAndLines);
   replaceLegend(legend);
 
+  // set the text attributes after calling replaceLegend() otherwise fon sizes will get overwritten
+  qreal generalFontSize = KGlobalSettings::generalFont().pointSizeF();
+  if (generalFontSize == -1)
+    generalFontSize = 8; // this is a fallback if the fontsize was specified in pixels
+  TextAttributes legendTextAttr(legend->textAttributes());
+  legendTextAttr.setPen(m_foregroundBrush.color());
+  legendTextAttr.setFontSize(KDChart::Measure(generalFontSize, KDChartEnums::MeasureCalculationModeAbsolute));
+  legend->setTextAttributes(legendTextAttr);
+
+  TextAttributes legendTitleTextAttr(legend->titleTextAttributes());
+  legendTitleTextAttr.setPen(m_foregroundBrush.color());
+  legendTitleTextAttr.setFontSize(KDChart::Measure(generalFontSize + 4, KDChartEnums::MeasureCalculationModeAbsolute));
+  legend->setTitleTextAttributes(legendTitleTextAttr);
+
   //this sets the line width only for line diagrams
   setLineWidth(config.chartLineWidth());
-  ::timetrace("finished drawing chart");
 
   //set data value attributes
   //make sure to show only the required number of fractional digits on the labels of the graph
@@ -493,16 +488,11 @@ void KReportChartView::drawPivotChart(const PivotGrid &grid, const MyMoneyReport
   dataValueAttr.setDecimalDigits(MyMoneyMoney::denomToPrec(MyMoneyFile::instance()->baseCurrency().smallestAccountFraction()));
   planeDiagram->setDataValueAttributes(dataValueAttr);
   planeDiagram->setAllowOverlappingDataValueTexts(true);
-}
 
-void KReportChartView::resizeEvent(QResizeEvent* event)
-{
-  Legend* legend = KReportChartView::legend();
-  if (legend) {
-    legend->setMaximumHeight(height() * LEGEND_HEIGHT_PERCENT);
-    legend->setMaximumWidth(width() * LEGEND_WIDTH_PERCENT);
+  if (qMin(static_cast<uint>(KMyMoneyGlobalSettings::maximumLegendItems()), legend->datasetCount()) < 2) {
+    // the legend is needed only if at least two data sets are rendered
+    removeLegend();
   }
-  Chart::resizeEvent(event);
 }
 
 unsigned KReportChartView::drawPivotRowSet(int rowNum, const PivotGridRowSet& rowSet, const ERowType rowType, const QString& legendText, int startColumn, int endColumn)
@@ -559,7 +549,7 @@ unsigned KReportChartView::drawPivotRowSet(int rowNum, const PivotGridRowSet& ro
 
 void KReportChartView::setDataCell(int row, int column, const double data)
 {
-  if (! coordinatePlane()->diagram()->datasetDimension() == 1)
+  if (coordinatePlane()->diagram()->datasetDimension() != 1)
     return;
 
   justifyModelSize(row + 1, column + 1);
@@ -570,7 +560,7 @@ void KReportChartView::setDataCell(int row, int column, const double data)
 
 void KReportChartView::setCellTip(int row, int column, QString tip)
 {
-  if (! coordinatePlane()->diagram()->datasetDimension() == 1)
+  if (coordinatePlane()->diagram()->datasetDimension() != 1)
     return;
 
   justifyModelSize(row + 1, column + 1);
@@ -635,7 +625,7 @@ void KReportChartView::drawLimitLine(const double limit)
 //TODO: add format to the line
 }
 
-void KReportChartView::removeLegend(void)
+void KReportChartView::removeLegend()
 {
   Legend* chartLegend = Chart::legend();
   delete chartLegend;
