@@ -96,6 +96,7 @@
 #include "kreportsview.h"
 #include "kbudgetview.h"
 #include "kforecastview.h"
+#include "konlinejoboutbox.h"
 #include "kmymoney.h"
 #include "kmymoneyutils.h"
 #include "models.h"
@@ -290,6 +291,16 @@ KMyMoneyView::KMyMoneyView(QWidget *parent)
   m_forecastViewFrame->setIcon(KIcon("view-financial-forecast"));
   connect(m_forecastView, SIGNAL(aboutToShow()), this, SIGNAL(aboutToChangeView()));
 
+  // Page 12
+  m_onlineJobOutboxView = new KOnlineJobOutbox();
+  m_onlineJobOutboxViewFrame = m_model->addPage(m_onlineJobOutboxView, i18n("Outbox"));
+  m_onlineJobOutboxViewFrame->setIcon(KIcon("online-banking"));
+  connect(m_onlineJobOutboxView, SIGNAL(sendJobs(QList<onlineJob>)), kmymoney, SLOT(slotOnlineJobSend(QList<onlineJob>)));
+  connect(m_onlineJobOutboxView, SIGNAL(editJob(QString)), kmymoney, SLOT(slotEditOnlineJob(QString)));
+  connect(m_onlineJobOutboxView, SIGNAL(newCreditTransfer()), kmymoney, SLOT(slotNewOnlineTransfer()));
+  connect(m_onlineJobOutboxView, SIGNAL(aboutToShow()), this, SIGNAL(aboutToChangeView()));
+  connect(m_onlineJobOutboxView, SIGNAL(showContextMenu(onlineJob)), kmymoney, SLOT(slotShowOnlineJobContextMenu()));
+
   //set the model
   setModel(m_model);
 
@@ -321,7 +332,7 @@ void KMyMoneyView::showTitleBar(bool show)
     m_header->setVisible(show);
 }
 
-void KMyMoneyView::updateViewType(void)
+void KMyMoneyView::updateViewType()
 {
   // set the face type
   KPageView::FaceType faceType = KPageView::List;
@@ -383,7 +394,7 @@ void KMyMoneyView::showPage(KPageWidgetItem* pageItem)
   }
 }
 
-bool KMyMoneyView::canPrint(void)
+bool KMyMoneyView::canPrint()
 {
   bool rc = (
               m_reportsViewFrame == currentPage()
@@ -446,7 +457,7 @@ bool KMyMoneyView::canEditTransactions(const KMyMoneyRegister::SelectedTransacti
   return rc;
 }
 
-bool KMyMoneyView::createNewTransaction(void)
+bool KMyMoneyView::createNewTransaction()
 {
   bool rc = false;
   KMyMoneyRegister::SelectedTransactions list;
@@ -478,7 +489,7 @@ void KMyMoneyView::newStorage(storageTypeE t)
 
 }
 
-void KMyMoneyView::removeStorage(void)
+void KMyMoneyView::removeStorage()
 {
   MyMoneyFile* file = MyMoneyFile::instance();
   IMyMoneyStorage* p = file->storage();
@@ -513,7 +524,8 @@ void KMyMoneyView::enableViewsIfFileOpen()
     m_reportsViewFrame->setEnabled(m_fileOpen);
   if (m_forecastViewFrame->isEnabled() != m_fileOpen)
     m_forecastViewFrame->setEnabled(m_fileOpen);
-
+  if (m_onlineJobOutboxViewFrame->isEnabled() != m_fileOpen)
+    m_onlineJobOutboxViewFrame->setEnabled(m_fileOpen);
   emit viewStateChanged(m_fileOpen);
 }
 
@@ -588,12 +600,12 @@ void KMyMoneyView::slotShowReport(const MyMoneyReport& report)
   m_reportsView->slotOpenReport(report);
 }
 
-bool KMyMoneyView::fileOpen(void)
+bool KMyMoneyView::fileOpen()
 {
   return m_fileOpen;
 }
 
-void KMyMoneyView::closeFile(void)
+void KMyMoneyView::closeFile()
 {
   if (m_reportsView)
     m_reportsView->slotCloseAll();
@@ -621,6 +633,8 @@ void KMyMoneyView::closeFile(void)
   disconnect(MyMoneyFile::instance(), SIGNAL(valueChanged(MyMoneyAccount)),
              Models::instance()->institutionsModel(), SLOT(slotBalanceOrValueChanged(MyMoneyAccount)));
 
+  disconnect(MyMoneyFile::instance(), SIGNAL(dataChanged()), m_homeView, SLOT(slotLoadView()));
+
   // notify the models that the file is going to be closed (we should have something like dataChanged that reaches the models first)
   Models::instance()->fileClosed();
 
@@ -1093,6 +1107,9 @@ bool KMyMoneyView::initializeStorage()
   MyMoneyFile::instance()->preloadCache();
   MyMoneyFile::instance()->forceDataChanged();
 
+  // views can wait since they are going to be refresed in slotRefreshViews
+  connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), m_homeView, SLOT(slotLoadView()));
+
   // if we currently see a different page, then select the right one
   if (m_model->index(page).row() != KPageView::currentPage().row()) {
     showPage(page);
@@ -1290,7 +1307,8 @@ bool KMyMoneyView::saveAsDatabase(const KUrl& url)
       if (KMessageBox::warningContinueCancel(0,
                                              i18n("Database contains data which must be removed before using Save As.\n"
                                                   "Do you wish to continue?"), "Database not empty") == KMessageBox::Continue) {
-        if (writer->open(url, QIODevice::WriteOnly, true) == 0) canWrite = true;
+        if (writer->open(url, QIODevice::WriteOnly, true) == 0)
+          canWrite = true;
       } else {
         delete writer;
         return false;
@@ -1319,7 +1337,7 @@ bool KMyMoneyView::saveAsDatabase(const KUrl& url)
   return (rc);
 }
 
-bool KMyMoneyView::dirty(void)
+bool KMyMoneyView::dirty()
 {
   if (!fileOpen())
     return false;
@@ -1355,7 +1373,7 @@ void KMyMoneyView::finishReconciliation(const MyMoneyAccount& /* account */)
   emit reconciliationStarts(MyMoneyAccount(), QDate(), MyMoneyMoney());
 }
 
-void KMyMoneyView::newFile(void)
+void KMyMoneyView::newFile()
 {
   closeFile();
   m_fileType = KmmXML; // assume native type until saved
@@ -1384,7 +1402,7 @@ void KMyMoneyView::slotSetBaseCurrency(const MyMoneySecurity& baseCurrency)
   }
 }
 
-void KMyMoneyView::selectBaseCurrency(void)
+void KMyMoneyView::selectBaseCurrency()
 {
   MyMoneyFile* file = MyMoneyFile::instance();
 
@@ -1469,7 +1487,7 @@ void KMyMoneyView::loadDefaultCurrency(const MyMoneySecurity& currency, const bo
   }
 }
 
-void KMyMoneyView::loadDefaultCurrencies(void)
+void KMyMoneyView::loadDefaultCurrencies()
 {
   // more information can be obtained from http://en.wikipedia.org/wiki/Currency_codes
 
@@ -1619,7 +1637,7 @@ void KMyMoneyView::loadDefaultCurrencies(void)
   loadDefaultCurrency(MyMoneySecurity("TOP", i18n("Tongan Pa'anga")), create);
   loadDefaultCurrency(MyMoneySecurity("TTD", i18n("Trinidad and Tobago Dollar"), "$"), create);
   loadDefaultCurrency(MyMoneySecurity("TND", i18n("Tunisian Dinar"),         "TND", 1000, 1000), create);
-  loadDefaultCurrency(MyMoneySecurity("TRY", i18n("Turkish Lira (new)"), QChar(0x20BA)), create);
+  loadDefaultCurrency(MyMoneySecurity("TRY", i18n("Turkish Lira"), QChar(0x20BA)), create);
   loadDefaultCurrency(MyMoneySecurity("TMM", i18n("Turkmenistan Manat")), create);
   loadDefaultCurrency(MyMoneySecurity("USD", i18n("US Dollar"),              "$"), create);
   loadDefaultCurrency(MyMoneySecurity("UGX", i18n("Uganda Shilling")), create);
@@ -1665,7 +1683,7 @@ void KMyMoneyView::loadAncientCurrency(const QString& id, const QString& name, c
   }
 }
 
-void KMyMoneyView::loadAncientCurrencies(void)
+void KMyMoneyView::loadAncientCurrencies()
 {
   loadAncientCurrency("ATS", i18n("Austrian Schilling"), "ÖS", QDate(1998, 12, 31), MyMoneyMoney(10000, 137603), "EUR");
   loadAncientCurrency("DEM", i18n("German Mark"), "DM", QDate(1998, 12, 31), MyMoneyMoney(100000, 195583), "EUR");
@@ -1690,7 +1708,7 @@ void KMyMoneyView::loadAncientCurrencies(void)
   loadAncientCurrency("SIT", i18n("Slovenian Tolar"), "SIT", QDate(2006, 12, 31), MyMoneyMoney(100, 23964), "EUR");
 
   // Source: http://www.tf-portfoliosolutions.net/products/turkishlira.aspx
-  loadAncientCurrency("TRL", i18n("Turkish Lira"), "TL", QDate(2004, 12, 31), MyMoneyMoney(1, 1000000), "TRY");
+  loadAncientCurrency("TRL", i18n("Turkish Lira (old)"), "TL", QDate(2004, 12, 31), MyMoneyMoney(1, 1000000), "TRY");
 
   // Source: http://www.focus.de/finanzen/news/malta-und-zypern_aid_66058.html
   loadAncientCurrency("MTL", i18n("Maltese Lira"), "MTL", QDate(2008, 1, 1), MyMoneyMoney(429300, 1000000), "EUR");
@@ -1770,13 +1788,13 @@ void KMyMoneyView::slotCurrentPageChanged(const QModelIndex current, const QMode
    Instead, create a new function, fixFile_n, and modify the initializeStorage()
    logic above to call it */
 
-void KMyMoneyView::fixFile_3(void)
+void KMyMoneyView::fixFile_3()
 {
   // make sure each storage object contains a (unique) id
   MyMoneyFile::instance()->storageId();
 }
 
-void KMyMoneyView::fixFile_2(void)
+void KMyMoneyView::fixFile_2()
 {
   MyMoneyFile* file = MyMoneyFile::instance();
   MyMoneyTransactionFilter filter;
@@ -1822,7 +1840,7 @@ void KMyMoneyView::fixFile_2(void)
   qDebug("%d transactions fixed in fixFile_2", count);
 }
 
-void KMyMoneyView::fixFile_1(void)
+void KMyMoneyView::fixFile_1()
 {
   // we need to fix reports. If the account filter list contains
   // investment accounts, we need to add the stock accounts to the list
@@ -1891,7 +1909,7 @@ if (!m_accountsView->allItemsSelected())
 
 
 
-void KMyMoneyView::fixFile_0(void)
+void KMyMoneyView::fixFile_0()
 {
   /* (Ace) I am on a crusade against file fixups.  Whenever we have to fix the
    * file, it is really a warning.  So I'm going to print a debug warning, and
@@ -2060,7 +2078,7 @@ void KMyMoneyView::createSchedule(MyMoneySchedule newSchedule, MyMoneyAccount& n
   }
 }
 
-void KMyMoneyView::fixTransactions_0(void)
+void KMyMoneyView::fixTransactions_0()
 {
   MyMoneyFile* file = MyMoneyFile::instance();
 
@@ -2265,7 +2283,7 @@ void KMyMoneyView::fixDuplicateAccounts_0(MyMoneyTransaction& t)
   qDebug("Duplicate account in transaction %s", qPrintable(t.id()));
 }
 
-void KMyMoneyView::slotPrintView(void)
+void KMyMoneyView::slotPrintView()
 {
   if (m_reportsViewFrame == currentPage())
     m_reportsView->slotPrintView();
@@ -2325,7 +2343,7 @@ void KMyMoneyViewBase::addWidget(QWidget* w)
   d->m_viewLayout->addWidget(w);
 }
 
-QVBoxLayout* KMyMoneyViewBase::layout(void) const
+QVBoxLayout* KMyMoneyViewBase::layout() const
 {
   return d->m_viewLayout;
 }
