@@ -30,8 +30,7 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA
  ****************************************************************************/
 
 /***************************************************************************
