@@ -384,7 +384,7 @@ int Transaction::formRowHeight(int /*row*/)
   return m_formRowHeight;
 }
 
-int Transaction::formRowHeight(void) const
+int Transaction::formRowHeight() const
 {
   if (m_formRowHeight < 0) {
     // determine the height of the objects in the table
@@ -493,7 +493,7 @@ void Transaction::arrangeWidget(QTableWidget* tbl, int row, int col, QWidget* w)
   }
 }
 
-bool Transaction::haveNumberField(void) const
+bool Transaction::haveNumberField() const
 {
   bool rc = true;
   switch (m_account.accountType()) {
@@ -582,7 +582,7 @@ QString Transaction::reconcileState(bool text) const
   return txt;
 }
 
-void Transaction::startEditMode(void)
+void Transaction::startEditMode()
 {
   m_inEdit = true;
 
@@ -595,7 +595,7 @@ void Transaction::startEditMode(void)
     setNumRowsRegister(numRowsRegister(true));
 }
 
-void Transaction::leaveEditMode(void)
+void Transaction::leaveEditMode()
 {
   // show the original tabbar since the edit tabbar was removed
   KMyMoneyTransactionForm::TransactionForm* form = dynamic_cast<KMyMoneyTransactionForm::TransactionForm*>(m_form);
@@ -621,7 +621,7 @@ void Transaction::singleLineMemo(QString& txt, const MyMoneySplit& split) const
   txt.replace('\n', ", ");
 }
 
-int Transaction::rowHeightHint(void) const
+int Transaction::rowHeightHint() const
 {
   return m_inEdit ? formRowHeight() : RegisterItem::rowHeightHint();
 }
@@ -836,7 +836,7 @@ void StdTransaction::setupFormHeader(const QString& id)
   }
 }
 
-KMyMoneyRegister::Action StdTransaction::actionType(void) const
+KMyMoneyRegister::Action StdTransaction::actionType() const
 {
   KMyMoneyRegister::Action action = ActionNone;
 
@@ -1365,13 +1365,18 @@ int StdTransaction::numRowsRegister(bool expanded) const
 
 TransactionEditor* StdTransaction::createEditor(TransactionEditorContainer* regForm, const KMyMoneyRegister::SelectedTransactions& list, const QDate& lastPostDate)
 {
+#ifndef KMM_DESIGNER
   m_inRegisterEdit = regForm == m_parent;
   return new StdTransactionEditor(regForm, this, list, lastPostDate);
+#else
+  return NULL;
+#endif
 }
 
 InvestTransaction::InvestTransaction(Register *parent, const MyMoneyTransaction& transaction, const MyMoneySplit& split, int uniqueId) :
     Transaction(parent, transaction, split, uniqueId)
 {
+#ifndef KMM_DESIGNER
   // dissect the transaction into its type, splits, currency, security etc.
   InvestTransactionEditor::dissectTransaction(m_transaction, m_split,
       m_assetAccountSplit,
@@ -1380,6 +1385,7 @@ InvestTransaction::InvestTransaction(Register *parent, const MyMoneyTransaction&
       m_security,
       m_currency,
       m_transactionType);
+#endif
 
   QList<MyMoneySplit>::ConstIterator it_s;
   for (it_s = m_feeSplits.constBegin(); it_s != m_feeSplits.constEnd(); ++it_s) {
@@ -2065,7 +2071,7 @@ int InvestTransaction::numRowsRegister(bool expanded) const
   return numRows;
 }
 
-bool InvestTransaction::haveShares(void) const
+bool InvestTransaction::haveShares() const
 {
   bool rc = true;
   switch (m_transactionType) {
@@ -2082,7 +2088,7 @@ bool InvestTransaction::haveShares(void) const
   return rc;
 }
 
-bool InvestTransaction::haveFees(void) const
+bool InvestTransaction::haveFees() const
 {
   bool rc = true;
   switch (m_transactionType) {
@@ -2098,7 +2104,7 @@ bool InvestTransaction::haveFees(void) const
   return rc;
 }
 
-bool InvestTransaction::haveInterest(void) const
+bool InvestTransaction::haveInterest() const
 {
   bool rc = false;
   switch (m_transactionType) {
@@ -2117,7 +2123,7 @@ bool InvestTransaction::haveInterest(void) const
   return rc;
 }
 
-bool InvestTransaction::havePrice(void) const
+bool InvestTransaction::havePrice() const
 {
   bool rc = false;
   switch (m_transactionType) {
@@ -2133,7 +2139,7 @@ bool InvestTransaction::havePrice(void) const
   return rc;
 }
 
-bool InvestTransaction::haveAmount(void) const
+bool InvestTransaction::haveAmount() const
 {
   bool rc = false;
   switch (m_transactionType) {
@@ -2151,7 +2157,7 @@ bool InvestTransaction::haveAmount(void) const
   return rc;
 }
 
-bool InvestTransaction::haveAssetAccount(void) const
+bool InvestTransaction::haveAssetAccount() const
 {
   bool rc = true;
   switch (m_transactionType) {
@@ -2168,7 +2174,7 @@ bool InvestTransaction::haveAssetAccount(void) const
   return rc;
 }
 
-bool InvestTransaction::haveSplitRatio(void) const
+bool InvestTransaction::haveSplitRatio() const
 {
   return m_transactionType == MyMoneySplit::SplitShares;
 }
@@ -2182,7 +2188,11 @@ void InvestTransaction::splits(MyMoneySplit& assetAccountSplit, QList<MyMoneySpl
 
 TransactionEditor* InvestTransaction::createEditor(TransactionEditorContainer* regForm, const KMyMoneyRegister::SelectedTransactions& list, const QDate& lastPostDate)
 {
+#ifndef KMM_DESIGNER
   m_inRegisterEdit = regForm == m_parent;
   return new InvestTransactionEditor(regForm, this, list, lastPostDate);
+#else
+  return NULL;
+#endif
 }
 
