@@ -1,5 +1,5 @@
 /****************************************************************************
-** Copyright (C) 2001-2011 Klaralvdalens Datakonsult AB.  All rights reserved.
+** Copyright (C) 2001-2012 Klaralvdalens Datakonsult AB.  All rights reserved.
 **
 ** This file is part of the KD Chart library.
 **
@@ -105,7 +105,7 @@ CartesianDiagramDataCompressor::DataValueAttributesList CartesianDiagramDataComp
             while (i != allAttrs.constEnd()) {
                 if( i.value() == attrs ){
                     isDuplicate = true;
-                    break;
+                    continue;
                 }
                 ++i;
             }
@@ -549,7 +549,8 @@ void CartesianDiagramDataCompressor::rebuildCache() const
     Q_ASSERT( m_datasetDimension != 0 );
 
     m_data.clear();
-    const int columnCount = m_model ? m_model->columnCount( m_rootIndex ) / m_datasetDimension : 0;
+    const int columnDivisor = m_datasetDimension != 2 ? 1 : m_datasetDimension;
+    const int columnCount = m_model ? m_model->columnCount( m_rootIndex ) / columnDivisor : 0;
     const int rowCount = qMin( m_model ? m_model->rowCount( m_rootIndex ) : 0, m_xResolution );
     m_data.resize( columnCount );
     for ( int i = 0; i < columnCount; ++i ) {
@@ -607,8 +608,8 @@ QPair< QPointF, QPointF > CartesianDiagramDataCompressor::dataBoundaries() const
     // NOTE: calculateDataBoundaries must return the *real* data boundaries!
     //       i.e. we may NOT fake yMin to be qMin( 0.0, yMin )
     //       (khz, 2008-01-24)
-    const QPointF bottomLeft( QPointF( xMin, yMin ) );
-    const QPointF topRight( QPointF( xMax, yMax ) );
+    const QPointF bottomLeft( xMin, yMin );
+    const QPointF topRight( xMax, yMax );
     return QPair< QPointF, QPointF >( bottomLeft, topRight );
 }
         
@@ -623,7 +624,7 @@ void CartesianDiagramDataCompressor::retrieveModelData( const CachePosition& pos
         bool forceHidden = false;
         result.hidden = true;
         const QModelIndexList indexes = mapToModel( position );
-        if( m_datasetDimension != 1 )
+        if( m_datasetDimension == 2 )
         {
             Q_ASSERT( indexes.count() == 2 );
             
